==> test-4.33.0-beta.0.tgz: package/bin/karma/index.js <==
// https://github.com/developit/karmatic/blob/master/src/index.js
const {Server} = require('karma')
const config = require('./config')
const {clientConfig} = require('../../src/config')
const CWD = process.cwd()

module.exports = ({ci, pattern, ignorePattern, srcPattern, timeout, watch}) => {
  if (timeout) config.browserDisconnectTimeout = timeout
  if (ignorePattern) config.exclude = [ignorePattern]

  if (ci) {
    config.browsers = ['Firefox']
    config.reporters = ['coverage'].concat(config.reporters)
    config.preprocessors = {
      'src/**/*.js': ['coverage']
    }
    config.coverageReporter = {
      dir: `${CWD}/coverage`,
      reporters: [
        {type: 'cobertura', subdir: '.', file: 'coverage.xml'},
        {type: 'html', subdir: 'report-html'},
        {type: 'text-summary'}
      ]
    }

    config.client.captureConsole = Boolean(clientConfig.captureConsole)
  }

  if (clientConfig.browserDisconnectTolerance) {
    config.browserDisconnectTolerance = clientConfig.browserDisconnectTolerance
  }

  if (watch) {
    config.singleRun = false
    config.reporters = ['clear-screen'].concat(config.reporters)
  }

  config.files = [
    `${CWD}/node_modules/@babel/polyfill/dist/polyfill.min.js`,
    srcPattern ? `${CWD}/${srcPattern}` : '',
    `${CWD}/${pattern}`
  ].filter(Boolean)

  config.preprocessors = {
    [pattern]: ['webpack'],
    ...(srcPattern && {[srcPattern]: ['webpack']})
  }

  config.client.mocha = {
    ...config.client.mocha,
    ...(timeout && {timeout})
  }

  return new Promise((resolve, reject) => {
    const server = new Server(config, code => {
      if (code === 0) return resolve()
      const err = new Error(`Exit ${code}`)
      err.code = code
      reject(err)
    })

    server.start()
  })
}

==> test-8.6.0-beta.0.tgz: package/bin/karma/index.js <==
// https://github.com/developit/karmatic/blob/master/src/index.js
const {
  config: {parseConfig},
  Server
} = require('karma')
const config = require('./config.js')
const CWD = process.cwd()

module.exports = async ({
  ci,
  coverage,
  ignorePattern,
  pattern,
  srcPattern,
  timeout,
  watch
}) => {
  if (timeout) config.browserDisconnectTimeout = timeout
  if (ignorePattern) config.exclude = [ignorePattern]

  if (ci) {
    config.browsers = ['ChromeHeadless']
  }

  if (coverage || ci) {
    config.reporters = ['coverage'].concat(config.reporters)

    config.preprocessors = {
      'src/**/*.js': ['coverage']
    }
    config.coverageReporter = {
      dir: `${CWD}/coverage`,
      reporters: [
        {type: 'cobertura', subdir: '.', file: 'coverage.xml'},
        {type: 'html', subdir: 'report-html'},
        {type: 'json-summary', subdir: '.', file: 'coverage.json'},
        {type: 'text-summary'}
      ]
    }
  }

  if (watch) {
    config.singleRun = false
  }

  config.files = [
    srcPattern ? `${CWD}/${srcPattern}` : '',
    `${CWD}/${pattern}`
  ].filter(Boolean)

  config.preprocessors = {
    ...config.preprocessors,
    [pattern]: ['webpack'],
    ...(srcPattern && {[srcPattern]: ['webpack']})
  }

  config.client.mocha = {
    ...config.client.mocha,
    ...(timeout && {timeout})
  }

  const karmaConfig = await parseConfig(null, config, {
    promiseConfig: true,
    throwErrors: true
  })

  return new Promise((resolve, reject) => {
    const server = new Server(karmaConfig, code => {
      if (code === 0) return resolve()
      const err = new Error(`Exit ${code}`)
      err.code = code
      reject(err)
    })

    server.start()
  })
}
